==> qt6-base-6.8.0-2-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6HostInfo/Qt6HostInfoConfig.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QtHostInfoConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/Qt6HostInfo" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

####################################################################################

set(QT6_HOST_INFO_BINDIR "lib/qt6/bin")
set(QT6_HOST_INFO_INCLUDEDIR "include/qt6")
set(QT6_HOST_INFO_LIBDIR "lib")
set(QT6_HOST_INFO_MKSPECSDIR "lib/qt6/mkspecs")
set(QT6_HOST_INFO_ARCHDATADIR "lib/qt6")
set(QT6_HOST_INFO_PLUGINSDIR "lib/qt6/plugins")
set(QT6_HOST_INFO_LIBEXECDIR "lib")
set(QT6_HOST_INFO_QMLDIR "lib/qt6/qml")
set(QT6_HOST_INFO_DATADIR "share/qt6")
set(QT6_HOST_INFO_DOCDIR "share/doc/qt6")
set(QT6_HOST_INFO_TRANSLATIONSDIR "share/qt6/translations")
set(QT6_HOST_INFO_SYSCONFDIR "etc/xdg")
set(QT6_HOST_INFO_EXAMPLESDIR "share/doc/qt6/examples")
set(QT6_HOST_INFO_TESTSDIR "tests")
set(QT6_HOST_INFO_DESCRIPTIONSDIR "lib/qt6/modules")
set(QT6_HOST_INFO_QMAKE_MKSPEC "linux-g++")
set(QT6_HOST_INFO_ARCH "x86_64")
set(QT6_HOST_INFO_SUBARCHS "")
set(QT6_HOST_INFO_BUILDABI "x86_64-little_endian-lp64")
set(QT6_HOST_INFO_IS_SHARED_LIBS_BUILD "ON")

==> qt6-base-6.8.1-1.1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6HostInfo/Qt6HostInfoConfig.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QtHostInfoConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/Qt6HostInfo" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

####################################################################################

set(QT6_HOST_INFO_BINDIR "lib/qt6/bin")
set(QT6_HOST_INFO_INCLUDEDIR "include/qt6")
set(QT6_HOST_INFO_LIBDIR "lib")
set(QT6_HOST_INFO_MKSPECSDIR "lib/qt6/mkspecs")
set(QT6_HOST_INFO_ARCHDATADIR "lib/qt6")
set(QT6_HOST_INFO_PLUGINSDIR "lib/qt6/plugins")
set(QT6_HOST_INFO_LIBEXECDIR "lib/qt6")
set(QT6_HOST_INFO_QMLDIR "lib/qt6/qml")
set(QT6_HOST_INFO_DATADIR "share/qt6")
set(QT6_HOST_INFO_DOCDIR "share/doc/qt6")
set(QT6_HOST_INFO_TRANSLATIONSDIR "share/qt6/translations")
set(QT6_HOST_INFO_SYSCONFDIR "etc/xdg")
set(QT6_HOST_INFO_EXAMPLESDIR "share/doc/qt6/examples")
set(QT6_HOST_INFO_TESTSDIR "tests")
set(QT6_HOST_INFO_DESCRIPTIONSDIR "lib/qt6/modules")
set(QT6_HOST_INFO_QMAKE_MKSPEC "linux-g++")
set(QT6_HOST_INFO_ARCH "x86_64")
set(QT6_HOST_INFO_SUBARCHS "avx;avx2;bmi;bmi2;cx16;f16c;fma;lzcnt;movbe;pclmul;popcnt;sse3;ssse3;sse4.1;sse4.2;sse4")
set(QT6_HOST_INFO_BUILDABI "x86_64-little_endian-lp64")
set(QT6_HOST_INFO_IS_SHARED_LIBS_BUILD "ON")
